@@ -38,7 +38,6 @@ class Q_DECL_HIDDEN ChangeFetchJob::Private
 {
   public:
     Private(ChangeFetchJob *parent);
-    QNetworkRequest createRequest(const QUrl &url);
 
     QString changeId;
 
@@ -46,6 +45,8 @@ class Q_DECL_HIDDEN ChangeFetchJob::Private
     bool includeSubscribed;
     int maxResults;
     qlonglong startChangeId;
+    bool includeItemsFromAllDrives;
+    bool supportsAllDrives;
 
   private:
     ChangeFetchJob *q;
@@ -56,20 +57,12 @@ ChangeFetchJob::Private::Private(ChangeFetchJob *parent):
     includeSubscribed(true),
     maxResults(0),
     startChangeId(0),
+    includeItemsFromAllDrives(true),
+    supportsAllDrives(true),
     q(parent)
 {
 }
 
-QNetworkRequest ChangeFetchJob::Private::createRequest(const QUrl &url)
-{
-    QNetworkRequest request;
-    request.setRawHeader("Authorization", "Bearer " + q->account()->accessToken().toLatin1());
-    request.setUrl(url);
-
-    return request;
-}
-
-
 ChangeFetchJob::ChangeFetchJob(const QString &changeId,
                                const AccountPtr &account,
                                QObject *parent):
@@ -149,6 +142,26 @@ qlonglong ChangeFetchJob::startChangeId() const
     return d->startChangeId;
 }
 
+bool ChangeFetchJob::includeItemsFromAllDrives() const
+{
+    return d->includeItemsFromAllDrives;
+}
+
+void ChangeFetchJob::setIncludeItemsFromAllDrives(bool includeItemsFromAllDrives)
+{
+    d->includeItemsFromAllDrives = includeItemsFromAllDrives;
+}
+
+bool ChangeFetchJob::supportsAllDrives() const
+{
+    return d->supportsAllDrives;
+}
+
+void ChangeFetchJob::setSupportsAllDrives(bool supportsAllDrives)
+{
+    d->supportsAllDrives = supportsAllDrives;
+}
+
 void ChangeFetchJob::start()
 {
     QUrl url;
@@ -163,12 +176,17 @@ void ChangeFetchJob::start()
         if (d->startChangeId > 0) {
             query.addQueryItem(QStringLiteral("startChangeId"), QString::number(d->startChangeId));
         }
+        query.addQueryItem(QStringLiteral("includeItemsFromAllDrives"), Utils::bool2Str(d->includeItemsFromAllDrives));
         url.setQuery(query);
     } else {
         url = DriveService::fetchChangeUrl(d->changeId);
     }
 
-    const QNetworkRequest request = d->createRequest(url);
+    QUrlQuery query(url);
+    query.addQueryItem(QStringLiteral("supportsAllDrives"), Utils::bool2Str(d->supportsAllDrives));
+    url.setQuery(query);
+
+    QNetworkRequest request(url);
     enqueueRequest(request);
 }
 
@@ -198,7 +216,7 @@ ObjectsList ChangeFetchJob::handleReplyWithItems(const QNetworkReply *reply,
     }
 
     if (feedData.nextPageUrl.isValid()) {
-        const QNetworkRequest request = d->createRequest(feedData.nextPageUrl);
+        QNetworkRequest request(feedData.nextPageUrl);
         enqueueRequest(request);
     }
 
